@@ -1,14 +1,18 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) from 2005 until 2008 Felipe Castro                      */
-/*  Copyright (C) from 2009 until 2019 The Free Software Foundation       */
+/*  Copyright (C) 2005-2021 Felipe Emmanuel Ferreira de Castro            */
 /*                                                                        */
-/*  This program is free software, licensed under the terms of the GNU    */
-/*  General Public License as published by the Free Software Foundation,  */
-/*  either version 3 of the License, or (at your option) any later        */
-/*  version. You should have received a copy of the GNU General Public    */
-/*  License along with this program. If not,                              */
-/*  see <https://www.gnu.org/licenses/>.                                  */
+/*  This file is part of Klavaro, which is a free software: you can       */
+/*  redistribute it and/or modify it under the terms of the GNU General   */
+/*  Public License as published by the Free Software Foundation, either   */
+/*  version 3 of the License, or (at your option) any later version.      */
+/*                                                                        */
+/*  Klavaro is distributed in the hope that it will be useful,            */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details (in the file COPYING).    */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Klavaro.  If not, see <https://www.gnu.org/licenses/>      */
 /**************************************************************************/
 
 /*
@@ -41,6 +45,7 @@
 "Français (fr) [azerty_fr]\n" \
 "Galego (gl) [qwerty_es]\n" \
 "Hrvatski (hr) [qwertz_hr]\n" \
+"Bahasa Indonesia (id) [qwerty_us]\n" \
 "Italiano (it) [qwerty_it]\n" \
 "Қазақ (kk) [jtsuken_kk]\n" \
 "한국어 (ko) [dubeolsik_kr]\n" \
@@ -57,6 +62,7 @@
 "Slovenščina (sl) [qwertz_si]\n" \
 "Српски (sr) [qwertz_rs]\n" \
 "Svenska (sv) [qwerty_se]\n" \
+"Türkçe (tr) [qwerty_tr]\n" \
 "తెలుగు (te) [qwerty_us]\n" \
 "Українська (uk) [jtsuken_ua]\n" \
 "اردو (ur) [qwerty_pk_crulp]\n" \
